==> qtjambi-scxml-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiScxml/QScxmlInvokableServiceFactory_shell.h <==
#ifndef QSCXMLINVOKABLESERVICEFACTORY_SHELL_H
#define QSCXMLINVOKABLESERVICEFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlInvokableServiceFactory_shell : public QScxmlInvokableServiceFactory, public QtJambiShellInterface
{
public:
    QScxmlInvokableServiceFactory_shell(const QScxmlExecutableContent::InvokeInfo& invokeInfo0, const QVector<qint32>& names1, const QVector<QScxmlExecutableContent::ParameterInfo>& parameters2, QObject* parent3 = nullptr);
    ~QScxmlInvokableServiceFactory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QScxmlInvokableService* invoke(QScxmlStateMachine* parentStateMachine0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlInvokableServiceFactory_access : public QScxmlInvokableServiceFactory
{
    jobject __qt_invoke_QScxmlStateMachine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentStateMachine0);
};

#endif // QSCXMLINVOKABLESERVICEFACTORY_SHELL_H

==> qtjambi-scxml-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiScxml/QScxmlInvokableServiceFactory_shell.h <==
#ifndef QSCXMLINVOKABLESERVICEFACTORY_SHELL_H
#define QSCXMLINVOKABLESERVICEFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlInvokableServiceFactory_shell : public QScxmlInvokableServiceFactory, public QtJambiShellInterface
{
public:
    QScxmlInvokableServiceFactory_shell(const QScxmlExecutableContent::InvokeInfo& invokeInfo0, const QList<qint32>& names1, const QList<QScxmlExecutableContent::ParameterInfo>& parameters2, QObject* parent3 = nullptr);
    ~QScxmlInvokableServiceFactory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QScxmlInvokableService* invoke(QScxmlStateMachine* parentStateMachine0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlInvokableServiceFactory_access : public QScxmlInvokableServiceFactory
{
    jobject __qt_invoke_QScxmlStateMachine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentStateMachine0);
};

#endif // QSCXMLINVOKABLESERVICEFACTORY_SHELL_H
